Logo Euclid.Kontur

ClipType Type

On Euclid.Kontur. The kind of boolean operation between a subject and a clip Kontur.

Record fields

Record Field Description

Difference

Full Usage: Difference

Field type: ClipType
Modifiers: static

Everything that is inside the subject but not inside the clip.

Field type: ClipType

Intersection

Full Usage: Intersection

Field type: ClipType
Modifiers: static

Everything that is inside the subject and inside the clip.

Field type: ClipType

Union

Full Usage: Union

Field type: ClipType
Modifiers: static

Everything that is inside the subject or inside the clip.

Field type: ClipType

Xor

Full Usage: Xor

Field type: ClipType
Modifiers: static

Everything that is inside exactly one of subject and clip.

Field type: ClipType

Type something to start searching.