Logo Euclid.Kontur

ClipType Module

Functions on the Euclid.Kontur.ClipType enum.

Functions and values

Function or value Description

combine op inSubject inClip

Full Usage: combine op inSubject inClip

Parameters:
    op : ClipType
    inSubject : bool
    inClip : bool

Returns: bool
Modifiers: inline

Combines the inside test of the subject and of the clip according to the operation. Returns TRUE if a point that is inside the subject if 'inSubject' and inside the clip if 'inClip' is inside the result of the operation.

op : ClipType
inSubject : bool
inClip : bool
Returns: bool

Type something to start searching.