ClipType Type
On Euclid.Kontur. The kind of boolean operation between a subject and a clip Kontur.
Record fields
| Record Field |
Description
|
|
Everything that is inside the subject but not inside the clip.
|
|
Everything that is inside the subject and inside the clip.
|
Everything that is inside the subject or inside the clip.
|
|
Everything that is inside exactly one of subject and clip.
|
Euclid.Kontur